"""All Item's defined in the diagram package.

This module makes it easier to load a diagram item.
"""

# ruff: noqa: F401,F403

from gaphor.UML.actions import *
from gaphor.UML.classes import *
from gaphor.UML.deployments import *
from gaphor.UML.general import *
from gaphor.UML.interactions import *
from gaphor.UML.profiles import *
from gaphor.UML.states import *
from gaphor.UML.usecases import *
